---
title: v2.1.0
---
## What's Changed
* fix listen does not check if message.from_user.id exists or not. Caus… by @WhaleFell in https://github.com/usernein/pyromod/pull/30

## New Contributors
* @WhaleFell made their first contribution in https://github.com/usernein/pyromod/pull/30

**Full Changelog**: https://github.com/usernein/pyromod/compare/v2.0.0...v2.1.0